.. _cache_ref:

:mod:`biolearn.cache`: Cache
==========================================

.. automodule:: biolearn.cache
   :no-members:
   :no-inherited-members:

**Classes**:

.. currentmodule:: biolearn.cache

.. autosummary::
   :toctree: generated/
   :template: class.rst

   NoCache
   LocalFolderCache